@@ -1,24 +1,21 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+/* A Bison parser, made by GNU Bison 2.5.  */
 
-/* Skeleton interface for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+/* Bison interface for Yacc-like parsers in C
+   
+      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,10 +26,11 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -61,36 +59,14 @@
      TOKEN_UNKNOWN = 277
    };
 #endif
-/* Tokens.  */
-#define TOKEN_ABBREV 258
-#define TOKEN_AT 259
-#define TOKEN_COMMA 260
-#define TOKEN_COMMENT 261
-#define TOKEN_ENTRY 262
-#define TOKEN_EQUALS 263
-#define TOKEN_FIELD 264
-#define TOKEN_INCLUDE 265
-#define TOKEN_INLINE 266
-#define TOKEN_KEY 267
-#define TOKEN_LBRACE 268
-#define TOKEN_LITERAL 269
-#define TOKEN_NEWLINE 270
-#define TOKEN_PREAMBLE 271
-#define TOKEN_RBRACE 272
-#define TOKEN_SHARP 273
-#define TOKEN_SPACE 274
-#define TOKEN_STRING 275
-#define TOKEN_VALUE 276
-#define TOKEN_UNKNOWN 277
-
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef int YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 extern YYSTYPE yylval;
@@ -109,3 +85,4 @@ typedef struct YYLTYPE
 #endif
 
 extern YYLTYPE yylloc;
+
